@@ -36,16 +36,16 @@ namespace Fm {
 class ExecFileDialog : public QDialog {
   Q_OBJECT
 public:
-  ~ExecFileDialog();
-  ExecFileDialog(const FileInfo& fileInfo, QWidget* parent = 0, Qt::WindowFlags f = 0);
+  ~ExecFileDialog() override;
+  ExecFileDialog(const FileInfo& fileInfo, QWidget* parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
 
   BasicFileLauncher::ExecAction result() {
     return result_;
   }
 
 protected:
-  virtual void accept() override;
-  virtual void reject() override;
+  void accept() override;
+  void reject() override;
 
 private:
   Ui::ExecFileDialog* ui;
