@@ -34,7 +34,8 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     acceptMode_{QFileDialog::AcceptOpen},
     confirmOverwrite_{true},
     modelFilter_{this},
-    noItemTooltip_{false} {
+    noItemTooltip_{false},
+    scrollPerPixel_{true} {
 
     ui->setupUi(this);
 
@@ -98,11 +99,6 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     ui->fileTypeCombo->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     ui->fileTypeCombo->setCurrentIndex(0);
 
-    QShortcut* shortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_H), this);
-    connect(shortcut, &QShortcut::activated, [this]() {
-        proxyModel_->setShowHidden(!proxyModel_->showHidden());
-    });
-
     // setup toolbar buttons
     auto toolbar = new QToolBar(this);
     // back button
@@ -200,6 +196,18 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
 
     menu->addSeparator();
 
+    // showing hidden files
+    auto showHiddenAction = menu->addAction(tr("Show Hidden"));
+    showHiddenAction->setCheckable(true);
+    connect(showHiddenAction, &QAction::triggered, [this](bool checked) {
+        proxyModel_->setShowHidden(checked);
+    });
+    // also add a separate shortcut for it
+    QShortcut* shortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_H), this);
+    connect(shortcut, &QShortcut::activated, [this]() {
+        proxyModel_->setShowHidden(!proxyModel_->showHidden());
+    });
+
     // thumbnail and tooltip actions
     auto thumbnailsAction = menu->addAction(tr("Show Thumbnails"));
     thumbnailsAction->setCheckable(true);
@@ -211,9 +219,22 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     connect(tooltipsAction, &QAction::triggered, [this](bool checked) {
         setNoItemTooltip(!checked);
     });
-    connect(menu, &QMenu::aboutToShow, [this, thumbnailsAction, tooltipsAction]() {
-        thumbnailsAction->setChecked(proxyModel_ ? proxyModel_->showThumbnails() : true);
+
+    // per-pixel action
+    auto perPixelAction = menu->addAction(tr("Smooth Scrolling"));
+    perPixelAction->setCheckable(true);
+    connect(perPixelAction, &QAction::triggered, [this](bool checked) {
+        setScrollPerPixel(checked);
+    });
+
+    // set the check states when the menu is about to appear
+    connect(menu, &QMenu::aboutToShow, [this, showHiddenAction, thumbnailsAction, tooltipsAction, perPixelAction]() {
+        showHiddenAction->setChecked(proxyModel_->showHidden());
+        thumbnailsAction->setChecked(proxyModel_->showThumbnails());
         tooltipsAction->setChecked(!noItemTooltip_);
+        perPixelAction->setVisible(viewMode_ == FolderView::DetailedListMode
+                                   || viewMode_ == FolderView::CompactMode);
+        perPixelAction->setChecked(scrollPerPixel_);
     });
 
     // Options menu button
@@ -404,6 +425,11 @@ void FileDialog::setNoItemTooltip(bool noItemTooltip) {
     }
 }
 
+void FileDialog::setScrollPerPixel(bool perPixel) {
+    scrollPerPixel_ = perPixel;
+    ui->folderView->setScrollPerPixel(scrollPerPixel_);
+}
+
 int FileDialog::bigIconSize() const {
     return ui->folderView->iconSize(FolderView::IconMode).width();
 }
@@ -435,6 +461,14 @@ void FileDialog::setThumbnailIconSize(int size) {
     }
 }
 
+QList<int> FileDialog::getHiddenColumns() const {
+    return ui->folderView->getHiddenColumns();
+}
+
+void FileDialog::setHiddenColumns(const QList<int> &columns) {
+    ui->folderView->setHiddenColumns(columns);
+}
+
 // This should always be used instead of getting text directly from the entry.
 QStringList FileDialog::parseNames() const {
     // parse the file names from the text entry
@@ -450,11 +484,7 @@ QStringList FileDialog::parseNames() const {
            && (firstQuote == 0 || fileNames.at(firstQuote - 1) != QLatin1Char('\\'))
            && fileNames.at(lastQuote - 1) != QLatin1Char('\\')) {
            // split the names
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
             QRegularExpression sep{QStringLiteral("\"\\s+\"")};  // separated with " "
-#else
-            QRegExp sep{QStringLiteral("\"\\s+\"")};  // separated with " "
-#endif
             parsedNames = fileNames.mid(firstQuote + 1, lastQuote - firstQuote - 1).split(sep);
             parsedNames.replaceInStrings(QLatin1String("\\\""), QLatin1String("\""));
         }
@@ -490,11 +520,7 @@ QString FileDialog::suffix(bool checkDefaultSuffix) const {
             auto right = currentNameFilter_.indexOf(QLatin1Char(')'), left);
             if(right != -1) {
                 QString nameFilter = currentNameFilter_.mid(left, right - left);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
                 QString suffix = nameFilter.simplified().split(QLatin1Char(' '), Qt::SkipEmptyParts).at(0);
-#else
-                QString suffix = nameFilter.simplified().split(QLatin1Char(' '), QString::SkipEmptyParts).at(0);
-#endif
                 left = suffix.indexOf(QLatin1Char('.')); // it can be like ".tar.xz"
                 if(left != -1 && suffix.size() - left > 1) {
                     return suffix.right(suffix.size() - left - 1);
@@ -1277,11 +1303,7 @@ bool FileDialog::FileDialogFilter::filterAcceptsRow(const ProxyFolderModel* /*mo
     bool nameMatched = false;
     auto& name = info->displayName();
     for(const auto& pattern: patterns_) {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
         if(name.indexOf(pattern) == 0) {
-#else
-        if(pattern.exactMatch(name)) {
-#endif
             nameMatched = true;
             break;
         }
@@ -1307,13 +1329,9 @@ void FileDialog::FileDialogFilter::update() {
     // parse the "*.ext1 *.ext2 *.ext3 ..." list into QRegularExpression objects
     const auto globs = nameFilter.simplified().split(QLatin1Char(' '));
     for(const auto& glob: globs) {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
         patterns_.emplace_back(QRegularExpression(QStringLiteral("\\A(?:")
                                                     + QRegularExpression::wildcardToRegularExpression(glob)
                                                     + QStringLiteral(")\\z"), QRegularExpression::CaseInsensitiveOption));
-#else
-        patterns_.emplace_back(QRegExp(glob, Qt::CaseInsensitive, QRegExp::Wildcard));
-#endif
     }
 }
 
