@@ -357,9 +357,10 @@ void PlacesView::onMoveBookmarkDown() {
     PlacesModelBookmarkItem* item = static_cast<PlacesModelBookmarkItem*>(model_->itemFromIndex(action->index()));
 
     int row = item->row();
-    if(row < model_->rowCount()) {
+    QModelIndex indx = proxyModel_->mapFromSource(model_->bookmarksRoot->index());
+    if(indx.isValid() && row < indx.model()->rowCount(indx) - 1) {
         auto bookmarkItem = item->bookmark();
-        Fm::Bookmarks::globalInstance()->reorder(bookmarkItem, row + 1);
+        Fm::Bookmarks::globalInstance()->reorder(bookmarkItem, row + 2); // see Bookmarks::reorder()
     }
 }
 
@@ -531,18 +532,23 @@ void PlacesView::contextMenuEvent(QContextMenuEvent* event) {
             // create context menu for bookmark item
             if(item->index().row() > 0) {
                 action = new PlacesModel::ItemAction(item->index(), tr("Move Bookmark Up"), menu);
+                action->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
                 connect(action, &QAction::triggered, this, &PlacesView::onMoveBookmarkUp);
                 menu->addAction(action);
             }
-            if(item->index().row() < model_->rowCount()) {
+            QModelIndex indx = proxyModel_->mapFromSource(model_->bookmarksRoot->index());
+            if(indx.isValid() && item->index().row() < indx.model()->rowCount(indx) - 1) {
                 action = new PlacesModel::ItemAction(item->index(), tr("Move Bookmark Down"), menu);
+                action->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
                 connect(action, &QAction::triggered, this, &PlacesView::onMoveBookmarkDown);
                 menu->addAction(action);
             }
             action = new PlacesModel::ItemAction(item->index(), tr("Rename Bookmark"), menu);
+            action->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
             connect(action, &QAction::triggered, this, &PlacesView::onRenameBookmark);
             menu->addAction(action);
             action = new PlacesModel::ItemAction(item->index(), tr("Remove Bookmark"), menu);
+            action->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
             connect(action, &QAction::triggered, this, &PlacesView::onDeleteBookmark);
             menu->addAction(action);
             break;
